import React, { useMemo } from 'react';
import { View } from 'react-native';
import Flex from './Flex';
import Divider from './Divider';

const Stack = _ref => {
  let {
    spacing = 0,
    divider = false,
    children,
    ...rest
  } = _ref;
  const dividerElement = useMemo(() => typeof divider === 'boolean' ? divider ? /*#__PURE__*/React.createElement(Divider, null) : null : divider, [divider]);
  const separatorStyle = useMemo(() => {
    var _rest$direction;

    if (!spacing) return undefined;
    const dir = rest.inline ? 'row' : (_rest$direction = rest.direction) !== null && _rest$direction !== void 0 ? _rest$direction : 'column';
    const spacingValue = spacing * 4;

    if (!!dividerElement) {
      return dir === 'row' || dir === 'row-reverse' ? {
        marginHorizontal: spacingValue
      } : {
        marginVertical: spacingValue
      };
    }

    return dir === 'row' || dir === 'row-reverse' ? {
      marginStart: spacingValue
    } : {
      marginTop: spacingValue
    };
  }, [dividerElement, spacing, rest.direction, rest.inline]);
  const validElements = React.Children.toArray(children).filter(child => /*#__PURE__*/React.isValidElement(child));
  const items = validElements.map((child, index) => {
    const key = typeof child.key !== 'undefined' ? child.key : index;
    const isLast = index === validElements.length - 1;
    return /*#__PURE__*/React.createElement(React.Fragment, {
      key: key
    }, child, !isLast && /*#__PURE__*/React.createElement(View, {
      style: separatorStyle
    }, dividerElement));
  });

  if (!spacing && !divider) {
    return /*#__PURE__*/React.createElement(Flex, rest, children);
  }

  return /*#__PURE__*/React.createElement(Flex, rest, items);
};

export default Stack;
//# sourceMappingURL=Stack.js.map