import React from 'react';
import { FlexStyle, ViewProps } from 'react-native';
export interface FlexProps extends ViewProps {
    /**
     * Determines how much the `<View />` will fill on the available space along the main axis.
     * Shorthand for `flex` (If `true` is passed, `flex` will be set to `1`).
     */
    fill?: boolean | number;
    /**
     * Shorthand for `{ flexDirection: "row }"`.
     */
    inline?: boolean;
    /**
     * Shorthand for `{ justifyContent: "center", alignItems: "center" }`.
     */
    center?: boolean;
    /**
     * Controls the direction in which the children of the `<View />` are laid out.
     * Shorthand for `flexDirection`.
     */
    direction?: FlexStyle['flexDirection'];
    /**
     * Describes how to align children within the main axis of the `<View />`.
     * Shorthand for `justifyContent`.
     */
    justify?: 'start' | 'end' | 'center' | 'between' | 'around' | 'evenly';
    /**
     * Describes how to align children within the cross axis of the `<View />`.
     * Shorthand for `alignItems`.
     */
    items?: 'start' | 'end' | 'center' | 'stretch' | 'baseline';
    /**
     * Shorthand for `alignSelf`.
     */
    self?: 'auto' | 'start' | 'end' | 'center' | 'stretch' | 'baseline';
    /**
     * Defines the distribution of lines along the cross-axis. This only has effect when items are wrapped to multiple lines using `flexWrap`.
     * Shorthand for `alignContent`.
     */
    content?: 'start' | 'end' | 'center' | 'stretch' | 'between' | 'around';
    /**
     * Controls what happens when children overflow the size of the `<View />` along the main axis.
     * Shorthand for `flexWrap` (If `true` is passed, `flexWrap` will be set to `"wrap"`).
     */
    wrap?: boolean | FlexStyle['flexWrap'];
    /**
     * Shorthand for `flexBasis`.
     */
    basis?: FlexStyle['flexBasis'];
    /**
     * Shorthand for `flexGrow`.
     */
    grow?: FlexStyle['flexGrow'];
    /**
     * Shorthand for `flexShrink`.
     */
    shrink?: FlexStyle['flexShrink'];
}
declare const Flex: React.FC<FlexProps>;
export default Flex;
